@@ -9,7 +9,6 @@ Creates a new pytplot variable as the time average of original.
 import numpy as np
 import pyspedas
 import pytplot
-from pytplot import store_data
 
 
 def avg_data(names, dt=None, width=60, noremainder=False,
@@ -65,8 +64,8 @@ def avg_data(names, dt=None, width=60, noremainder=False,
     if len(n_names) != len(old_names):
         n_names = [s + suffix for s in old_names]
 
-    for i, old in enumerate(old_names):
-        new = n_names[i]
+    for old_idx, old in enumerate(old_names):
+        new = n_names[old_idx]
 
         d = pytplot.data_quants[old].copy()
         data = d.values
@@ -87,7 +86,7 @@ def avg_data(names, dt=None, width=60, noremainder=False,
             # print(dim0, width)
             for i in range(0, dim0, width):
                 last = (i + width) if (i + width) < dim0 else dim0
-                idx = int(i + width/2)
+                # idx = int(i + width/2) # redefined below before it's ever used?
                 if (i + width > dim0) and noremainder:
                     continue  # Skip the last part of data.
                 else:
@@ -153,7 +152,7 @@ def avg_data(names, dt=None, width=60, noremainder=False,
                 new_data.append(nd0)
                 time0 = time1
 
-        store_data(new, data={'x': new_time, 'y': new_data})
+        pytplot.store_data(new, data={'x': new_time, 'y': new_data})
         # copy attributes
         pytplot.data_quants[new].attrs = d.attrs.copy()
 
