@@ -4,7 +4,7 @@ import pandas as pd
 import numpy as np
 
 from pyspedas.analysis.time_clip import time_clip as tclip
-from pytplot import store_data, options
+from pytplot import store_data
 
 def mms_load_att_tplot(filenames, level='def', probe='1', datatypes=['spinras', 'spindec'], suffix='', trange=None):
     """
