@@ -6,7 +6,8 @@ def emfisis(trange=['2018-11-5', '2018-11-6'],
         datatype='magnetometer', 
         level='l3',
         cadence='4sec', # for EMFISIS mag data
-        coord='sm', # for EMFISIS mag data
+        coord='sm', # for EMFISIS mag 
+        wavetype='waveform', # for EMFISIS waveform data
         suffix='',  
         get_support_data=False, 
         varformat=None,
@@ -17,8 +18,12 @@ def emfisis(trange=['2018-11-5', '2018-11-6'],
         time_clip=False):
     """
     This function loads data from the Electric and Magnetic Field Instrument Suite and Integrated Science (EMFISIS) instrument
+
+    For information on the EMFISIS data products, see:
+        https://emfisis.physics.uiowa.edu/data/level_descriptions
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -28,13 +33,55 @@ def emfisis(trange=['2018-11-5', '2018-11-6'],
             Spacecraft probe name ('a' or 'b'); default: a
 
         cadence: str
-            Data cadence (default: 4sec)
+            Data cadence (default: 4sec); other options: '1sec', 'hires'
 
         coord: str
             Data coordinate system (default: sm)
 
+        level: str
+            Data level; options: 'l1', 'l2', 'l3', l4'
+
         datatype: str
-            Data type; Valid options:
+            Data type; valid options:
+            Level 1:
+                'magnetometer'
+                'hfr'
+                'housekeeping'
+                'sc-hk'
+                'spaceweather'
+                'wfr'
+                'wna'
+
+            Level 2:
+                'magnetometer'
+                'wfr'
+                'hfr'
+                'housekeeping'
+
+            Level 3:
+                'magnetometer'
+
+            Level 4:
+                'density'
+                'wna-survey'
+
+        wavetype: str
+            Type of level 2 waveform data; valid options:
+                For WFR data:
+                'waveform' (default)
+                'waveform-continuous-burst'
+                'spectral-matrix'
+                'spectral-matrix-diagonal'
+                'spectral-matrix-diagonal-merged'
+
+                For HFR data:
+                'waveform'
+                'spectra'
+                'spectra-burst'
+                'spectra-merged'
+
+            For descriptions of these data, see:
+                https://emfisis.physics.uiowa.edu/data/L2_products
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -66,11 +113,12 @@ def emfisis(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
-    return load(instrument='emfisis', trange=trange, probe=probe, datatype=datatype, level=level, cadence=cadence, coord=coord, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    return load(instrument='emfisis', wavetype=wavetype, trange=trange, probe=probe, datatype=datatype, level=level, cadence=cadence, coord=coord, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
 def rbspice(trange=['2018-11-5', '2018-11-6'], 
         probe='a',
@@ -87,7 +135,8 @@ def rbspice(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Radiation Belt Storm Probes Ion Composition Experiment (RBSPICE) instrument
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -129,7 +178,8 @@ def rbspice(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -137,7 +187,7 @@ def rbspice(trange=['2018-11-5', '2018-11-6'],
 
 def efw(trange=['2015-11-5', '2015-11-6'], 
         probe='a',
-        datatype='', 
+        datatype='spec', 
         level='l3',
         suffix='',  
         get_support_data=False, 
@@ -150,7 +200,8 @@ def efw(trange=['2015-11-5', '2015-11-6'],
     """
     This function loads data from the Electric Field and Waves Suite (EFW)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -192,7 +243,8 @@ def efw(trange=['2015-11-5', '2015-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -214,7 +266,8 @@ def mageis(trange=['2015-11-5', '2015-11-6'],
     """
     This function loads data from the Energetic Particle, Composition, and Thermal Plasma Suite (ECT)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -256,7 +309,8 @@ def mageis(trange=['2015-11-5', '2015-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -278,7 +332,8 @@ def hope(trange=['2015-11-5', '2015-11-6'],
     """
     This function loads data from the Energetic Particle, Composition, and Thermal Plasma Suite (ECT)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -320,7 +375,8 @@ def hope(trange=['2015-11-5', '2015-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -342,7 +398,8 @@ def rept(trange=['2015-11-5', '2015-11-6'],
     """
     This function loads data from the Energetic Particle, Composition, and Thermal Plasma Suite (ECT)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -384,7 +441,8 @@ def rept(trange=['2015-11-5', '2015-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -405,7 +463,8 @@ def rps(trange=['2015-11-5', '2015-11-6'],
     """
     This function loads data from the Relativistic Proton Spectrometer (RPS)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -447,7 +506,8 @@ def rps(trange=['2015-11-5', '2015-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
